# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .memory_emotions_item import MemoryEmotionsItem
from .memory_type import MemoryType

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Memory(pydantic.BaseModel):
    type: MemoryType = pydantic.Field(
        description="Type of memory (`episode` or `belief`)"
    )
    agent_id: str = pydantic.Field(description="ID of the agent")
    user_id: str = pydantic.Field(description="ID of the user")
    content: str = pydantic.Field(description="Content of the memory")
    weight: typing.Optional[float] = pydantic.Field(
        description="Weight (importance) of the memory on a scale of 0-100"
    )
    created_at: dt.datetime = pydantic.Field(
        description="Memory created at (RFC-3339 format)"
    )
    last_accessed_at: typing.Optional[dt.datetime] = pydantic.Field(
        description="Memory last accessed at (RFC-3339 format)"
    )
    timestamp: typing.Optional[dt.datetime] = pydantic.Field(
        description="Memory happened at (RFC-3339 format)"
    )
    sentiment: typing.Optional[float] = pydantic.Field(
        description="Sentiment (valence) of the memory on a scale of -1 to 1"
    )
    duration: typing.Optional[float] = pydantic.Field(
        description="Duration of the Memory (in seconds)"
    )
    id: str = pydantic.Field(description="Memory id (UUID)")
    emotions: typing.Optional[typing.List[MemoryEmotionsItem]]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {
            "by_alias": True,
            "exclude_unset": True,
            **kwargs,
        }
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {
            "by_alias": True,
            "exclude_unset": True,
            **kwargs,
        }
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MemoryEmotionsItem(str, enum.Enum):
    ADMIRATION = "admiration"
    AMUSEMENT = "amusement"
    ANGER = "anger"
    ANNOYANCE = "annoyance"
    APPROVAL = "approval"
    CARING = "caring"
    CONFUSION = "confusion"
    CURIOSITY = "curiosity"
    DESIRE = "desire"
    DISAPPOINTMENT = "disappointment"
    DISAPPROVAL = "disapproval"
    DISGUST = "disgust"
    EMBARRASSMENT = "embarrassment"
    EXCITEMENT = "excitement"
    FEAR = "fear"
    GRATITUDE = "gratitude"
    GRIEF = "grief"
    JOY = "joy"
    LOVE = "love"
    NERVOUSNESS = "nervousness"
    NEUTRAL = "neutral"
    OPTIMISM = "optimism"
    PRIDE = "pride"
    REALIZATION = "realization"
    RELIEF = "relief"
    REMORSE = "remorse"
    SADNESS = "sadness"
    SARCASM = "sarcasm"
    SURPRISE = "surprise"

    def visit(
        self,
        admiration: typing.Callable[[], T_Result],
        amusement: typing.Callable[[], T_Result],
        anger: typing.Callable[[], T_Result],
        annoyance: typing.Callable[[], T_Result],
        approval: typing.Callable[[], T_Result],
        caring: typing.Callable[[], T_Result],
        confusion: typing.Callable[[], T_Result],
        curiosity: typing.Callable[[], T_Result],
        desire: typing.Callable[[], T_Result],
        disappointment: typing.Callable[[], T_Result],
        disapproval: typing.Callable[[], T_Result],
        disgust: typing.Callable[[], T_Result],
        embarrassment: typing.Callable[[], T_Result],
        excitement: typing.Callable[[], T_Result],
        fear: typing.Callable[[], T_Result],
        gratitude: typing.Callable[[], T_Result],
        grief: typing.Callable[[], T_Result],
        joy: typing.Callable[[], T_Result],
        love: typing.Callable[[], T_Result],
        nervousness: typing.Callable[[], T_Result],
        neutral: typing.Callable[[], T_Result],
        optimism: typing.Callable[[], T_Result],
        pride: typing.Callable[[], T_Result],
        realization: typing.Callable[[], T_Result],
        relief: typing.Callable[[], T_Result],
        remorse: typing.Callable[[], T_Result],
        sadness: typing.Callable[[], T_Result],
        sarcasm: typing.Callable[[], T_Result],
        surprise: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MemoryEmotionsItem.ADMIRATION:
            return admiration()
        if self is MemoryEmotionsItem.AMUSEMENT:
            return amusement()
        if self is MemoryEmotionsItem.ANGER:
            return anger()
        if self is MemoryEmotionsItem.ANNOYANCE:
            return annoyance()
        if self is MemoryEmotionsItem.APPROVAL:
            return approval()
        if self is MemoryEmotionsItem.CARING:
            return caring()
        if self is MemoryEmotionsItem.CONFUSION:
            return confusion()
        if self is MemoryEmotionsItem.CURIOSITY:
            return curiosity()
        if self is MemoryEmotionsItem.DESIRE:
            return desire()
        if self is MemoryEmotionsItem.DISAPPOINTMENT:
            return disappointment()
        if self is MemoryEmotionsItem.DISAPPROVAL:
            return disapproval()
        if self is MemoryEmotionsItem.DISGUST:
            return disgust()
        if self is MemoryEmotionsItem.EMBARRASSMENT:
            return embarrassment()
        if self is MemoryEmotionsItem.EXCITEMENT:
            return excitement()
        if self is MemoryEmotionsItem.FEAR:
            return fear()
        if self is MemoryEmotionsItem.GRATITUDE:
            return gratitude()
        if self is MemoryEmotionsItem.GRIEF:
            return grief()
        if self is MemoryEmotionsItem.JOY:
            return joy()
        if self is MemoryEmotionsItem.LOVE:
            return love()
        if self is MemoryEmotionsItem.NERVOUSNESS:
            return nervousness()
        if self is MemoryEmotionsItem.NEUTRAL:
            return neutral()
        if self is MemoryEmotionsItem.OPTIMISM:
            return optimism()
        if self is MemoryEmotionsItem.PRIDE:
            return pride()
        if self is MemoryEmotionsItem.REALIZATION:
            return realization()
        if self is MemoryEmotionsItem.RELIEF:
            return relief()
        if self is MemoryEmotionsItem.REMORSE:
            return remorse()
        if self is MemoryEmotionsItem.SADNESS:
            return sadness()
        if self is MemoryEmotionsItem.SARCASM:
            return sarcasm()
        if self is MemoryEmotionsItem.SURPRISE:
            return surprise()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MemoryType(str, enum.Enum):
    """
    Type of memory (`episode` or `belief`)
    """

    EPISODE = "episode"
    BELIEF = "belief"

    def visit(
        self,
        episode: typing.Callable[[], T_Result],
        belief: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MemoryType.EPISODE:
            return episode()
        if self is MemoryType.BELIEF:
            return belief()



# type: ignore
# ^^ Added to ignore pytype errors for this file as it uses hacks
from typing import TypedDict
from ..api.types import (
    CreateDoc,
    AgentDefaultSettings,
    FunctionDef,
    CreateToolRequest,
    Instruction,
    ChatSettingsResponseFormat,
    InputChatMlMessage,
    Tool,
)

ChatSettingsResponseFormatDict = TypedDict(
    "ChatSettingsResponseFormat",
    **{k: v.outer_type_ for k, v in ChatSettingsResponseFormat.__fields__.items()},
)
InputChatMlMessageDict = TypedDict(
    "InputChatMlMessage",
    **{k: v.outer_type_ for k, v in InputChatMlMessage.__fields__.items()},
)
ToolDict = TypedDict(
    "Tool",
    **{k: v.outer_type_ for k, v in Tool.__fields__.items()},
)

DocDict = TypedDict(
    "DocDict",
    **{k: v.outer_type_ for k, v in CreateDoc.__fields__.items()},
)
DefaultSettingsDict = TypedDict(
    "DefaultSettingsDict",
    **{k: v.outer_type_ for k, v in AgentDefaultSettings.__fields__.items()},
)
FunctionDefDict = TypedDict(
    "FunctionDefDict", **{k: v.outer_type_ for k, v in FunctionDef.__fields__.items()}
)
ToolDict = TypedDict(
    "ToolDict", **{k: v.outer_type_ for k, v in CreateToolRequest.__fields__.items()}
)
InstructionDict = TypedDict(
    "InstructionDict", **{k: v.outer_type_ for k, v in Instruction.__fields__.items()}
)



from typing import Optional

from environs import Env

from .api.environment import JulepApiEnvironment

env = Env()

JULEP_API_KEY: Optional[str] = env.str("JULEP_API_KEY", None)
JULEP_API_URL: Optional[str] = env.str(
    "JULEP_API_URL", JulepApiEnvironment.DEFAULT.value
)
